"""This module provides functionality to analyze intensities in images."""

import matplotlib.pyplot as plt
import numpy as np


def compare_intensities(img_a: np.ndarray, img_b: np.ndarray) -> None:
    """Show intensity histogram of two images in one plot.

    Args:
        img_a (np.ndarray): image
        img_b (np.ndarray): image
    """
    histogram_a = np.histogram(img_a,
                               bins=range(int(np.floor(np.max(img_a)) + 2)))
    histogram_a = (histogram_a[0], histogram_a[1][:-1])

    histogram_b = np.histogram(img_b,
                               bins=range(int(np.floor(np.max(img_b)) + 2)))
    histogram_b = (histogram_b[0], histogram_b[1][:-1])

    plt.figure(figsize=(10, 10))
    plt.title("Histogram of intensity")
    plt.plot(histogram_a[1], histogram_a[0], label="intensity distribution A")

    plt.plot(histogram_b[1], histogram_b[0], label="intensity distribution B")
    plt.yscale("log")
    plt.ylabel("distribution")
    plt.legend()

    plt.show()
    plt.close()