"""This module provides functionality to add different noise to an image."""

import numpy as np


def add_gaussian_noise(feature: np.ndarray,
                       mean: float = 0.0,
                       std: float = 0.01) -> np.ndarray:
    """Add a gaussian noise to a feature."""
    feature = feature.astype(np.float32)

    gaussian = np.random.normal(mean, std, feature.shape)

    return feature + gaussian


def add_speckle_noise(feature: np.ndarray,
                      mean: float = 0.0,
                      std: float = 0.01) -> np.ndarray:
    """Add a speckle noise to a feature."""
    feature = feature.astype(np.float32)

    gaussian = np.random.normal(mean, std, feature.shape)

    return feature + feature * gaussian