#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Jan 22 14:02:45 2025

@author: jsteiglechner
"""

from typing import Tuple

import nibabel as nib
import numpy as np


def generate_mp2rage_inversions(
        img_mag: nib.Nifti1Image,
        img_phs: nib.Nifti1Image,
) -> Tuple[nib.Nifti1Image, nib.Nifti1Image]:
    """
    Generate NIfTIs for inversion one and two from magnitude and phase

    Parameters
    ----------
    img_mag : nib.Nifti1Image
        NIfTI of magnitude.
    img_phs : nib.Nifti1Image
        NIfTI of phase.

    Returns
    -------
    nii_inv1 : nib.Nifti1Image
        Inversion One.
    nii_inv2 : nib.Nifti1Image
        Inversion Two.

    """
    img_inv1 = img_mag.dataobj[..., 0] * np.exp(img_phs.dataobj[..., 0] * 1.j)
    img_inv2 = img_mag.dataobj[..., 1] * np.exp(img_phs.dataobj[..., 1] * 1.j)

    nii_inv1 = nib.Nifti1Image(img_inv1, img_mag.affine)
    nii_inv2 = nib.Nifti1Image(img_inv2, img_mag.affine)

    return nii_inv1, nii_inv2
